@@ -3,6 +3,7 @@ from . import trees
 from . import net
 from . import bayes
 from . import distance
+from . import mixture
 
 def convert(estimator, kind=None, method='pymodule', dtype='float'):
     """Main entrypoint for converting a model"""
@@ -15,6 +16,8 @@ def convert(estimator, kind=None, method='pymodule', dtype='float'):
         return trees.Wrapper(estimator, method, dtype=dtype)
     elif kind in ['EllipticEnvelope']:
         return distance.Wrapper(estimator, method, dtype=dtype)
+    elif kind in ['GaussianMixture', 'BayesianGaussianMixture']:
+        return mixture.Wrapper(estimator, method, dtype=dtype)
     elif kind == 'MLPClassifier':
         return net.convert_sklearn_mlp(estimator, method)
     elif kind == 'Sequential':
